==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/V2beta2MetricStatusFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Boolean;
import java.lang.Object;

public class V2beta2MetricStatusFluentImpl<A extends V2beta2MetricStatusFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V2beta2MetricStatusFluent<A>{

    private V2beta2ExternalMetricStatusBuilder external;
    private V2beta2ObjectMetricStatusBuilder object;
    private V2beta2PodsMetricStatusBuilder pods;
    private V2beta2ResourceMetricStatusBuilder resource;
    private String type;

    public V2beta2MetricStatusFluentImpl(){
    }
    public V2beta2MetricStatusFluentImpl(V2beta2MetricStatus instance){
            this.withExternal(instance.getExternal());

            this.withObject(instance.getObject());

            this.withPods(instance.getPods());

            this.withResource(instance.getResource());

            this.withType(instance.getType());

    }

    
/**
 * This method has been deprecated, please use method buildExternal instead.
 * @return The buildable object.
 */
@Deprecated public V2beta2ExternalMetricStatus getExternal(){
            return this.external!=null?this.external.build():null;
    }

    public V2beta2ExternalMetricStatus buildExternal(){
            return this.external!=null?this.external.build():null;
    }

    public A withExternal(V2beta2ExternalMetricStatus external){
            _visitables.remove(this.external);
            if (external!=null){ this.external= new V2beta2ExternalMetricStatusBuilder(external); _visitables.add(this.external);} return (A) this;
    }

    public Boolean hasExternal(){
            return this.external != null;
    }

    public V2beta2MetricStatusFluent.ExternalNested<A> withNewExternal(){
            return new ExternalNestedImpl();
    }

    public V2beta2MetricStatusFluent.ExternalNested<A> withNewExternalLike(V2beta2ExternalMetricStatus item){
            return new ExternalNestedImpl(item);
    }

    public V2beta2MetricStatusFluent.ExternalNested<A> editExternal(){
            return withNewExternalLike(getExternal());
    }

    public V2beta2MetricStatusFluent.ExternalNested<A> editOrNewExternal(){
            return withNewExternalLike(getExternal() != null ? getExternal(): new V2beta2ExternalMetricStatusBuilder().build());
    }

    public V2beta2MetricStatusFluent.ExternalNested<A> editOrNewExternalLike(V2beta2ExternalMetricStatus item){
            return withNewExternalLike(getExternal() != null ? getExternal(): item);
    }

    
/**
 * This method has been deprecated, please use method buildObject instead.
 * @return The buildable object.
 */
@Deprecated public V2beta2ObjectMetricStatus getObject(){
            return this.object!=null?this.object.build():null;
    }

    public V2beta2ObjectMetricStatus buildObject(){
            return this.object!=null?this.object.build():null;
    }

    public A withObject(V2beta2ObjectMetricStatus object){
            _visitables.remove(this.object);
            if (object!=null){ this.object= new V2beta2ObjectMetricStatusBuilder(object); _visitables.add(this.object);} return (A) this;
    }

    public Boolean hasObject(){
            return this.object != null;
    }

    public V2beta2MetricStatusFluent.ObjectNested<A> withNewObject(){
            return new ObjectNestedImpl();
    }

    public V2beta2MetricStatusFluent.ObjectNested<A> withNewObjectLike(V2beta2ObjectMetricStatus item){
            return new ObjectNestedImpl(item);
    }

    public V2beta2MetricStatusFluent.ObjectNested<A> editObject(){
            return withNewObjectLike(getObject());
    }

    public V2beta2MetricStatusFluent.ObjectNested<A> editOrNewObject(){
            return withNewObjectLike(getObject() != null ? getObject(): new V2beta2ObjectMetricStatusBuilder().build());
    }

    public V2beta2MetricStatusFluent.ObjectNested<A> editOrNewObjectLike(V2beta2ObjectMetricStatus item){
            return withNewObjectLike(getObject() != null ? getObject(): item);
    }

    
/**
 * This method has been deprecated, please use method buildPods instead.
 * @return The buildable object.
 */
@Deprecated public V2beta2PodsMetricStatus getPods(){
            return this.pods!=null?this.pods.build():null;
    }

    public V2beta2PodsMetricStatus buildPods(){
            return this.pods!=null?this.pods.build():null;
    }

    public A withPods(V2beta2PodsMetricStatus pods){
            _visitables.remove(this.pods);
            if (pods!=null){ this.pods= new V2beta2PodsMetricStatusBuilder(pods); _visitables.add(this.pods);} return (A) this;
    }

    public Boolean hasPods(){
            return this.pods != null;
    }

    public V2beta2MetricStatusFluent.PodsNested<A> withNewPods(){
            return new PodsNestedImpl();
    }

    public V2beta2MetricStatusFluent.PodsNested<A> withNewPodsLike(V2beta2PodsMetricStatus item){
            return new PodsNestedImpl(item);
    }

    public V2beta2MetricStatusFluent.PodsNested<A> editPods(){
            return withNewPodsLike(getPods());
    }

    public V2beta2MetricStatusFluent.PodsNested<A> editOrNewPods(){
            return withNewPodsLike(getPods() != null ? getPods(): new V2beta2PodsMetricStatusBuilder().build());
    }

    public V2beta2MetricStatusFluent.PodsNested<A> editOrNewPodsLike(V2beta2PodsMetricStatus item){
            return withNewPodsLike(getPods() != null ? getPods(): item);
    }

    
/**
 * This method has been deprecated, please use method buildResource instead.
 * @return The buildable object.
 */
@Deprecated public V2beta2ResourceMetricStatus getResource(){
            return this.resource!=null?this.resource.build():null;
    }

    public V2beta2ResourceMetricStatus buildResource(){
            return this.resource!=null?this.resource.build():null;
    }

    public A withResource(V2beta2ResourceMetricStatus resource){
            _visitables.remove(this.resource);
            if (resource!=null){ this.resource= new V2beta2ResourceMetricStatusBuilder(resource); _visitables.add(this.resource);} return (A) this;
    }

    public Boolean hasResource(){
            return this.resource != null;
    }

    public V2beta2MetricStatusFluent.ResourceNested<A> withNewResource(){
            return new ResourceNestedImpl();
    }

    public V2beta2MetricStatusFluent.ResourceNested<A> withNewResourceLike(V2beta2ResourceMetricStatus item){
            return new ResourceNestedImpl(item);
    }

    public V2beta2MetricStatusFluent.ResourceNested<A> editResource(){
            return withNewResourceLike(getResource());
    }

    public V2beta2MetricStatusFluent.ResourceNested<A> editOrNewResource(){
            return withNewResourceLike(getResource() != null ? getResource(): new V2beta2ResourceMetricStatusBuilder().build());
    }

    public V2beta2MetricStatusFluent.ResourceNested<A> editOrNewResourceLike(V2beta2ResourceMetricStatus item){
            return withNewResourceLike(getResource() != null ? getResource(): item);
    }

    public String getType(){
            return this.type;
    }

    public A withType(String type){
            this.type=type; return (A) this;
    }

    public Boolean hasType(){
            return this.type != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V2beta2MetricStatusFluentImpl that = (V2beta2MetricStatusFluentImpl) o;
            if (external != null ? !external.equals(that.external) :that.external != null) return false;
            if (object != null ? !object.equals(that.object) :that.object != null) return false;
            if (pods != null ? !pods.equals(that.pods) :that.pods != null) return false;
            if (resource != null ? !resource.equals(that.resource) :that.resource != null) return false;
            if (type != null ? !type.equals(that.type) :that.type != null) return false;
            return true;
    }


    public class ExternalNestedImpl<N> extends V2beta2ExternalMetricStatusFluentImpl<V2beta2MetricStatusFluent.ExternalNested<N>> implements V2beta2MetricStatusFluent.ExternalNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V2beta2ExternalMetricStatusBuilder builder;
    
            ExternalNestedImpl(V2beta2ExternalMetricStatus item){
                    this.builder = new V2beta2ExternalMetricStatusBuilder(this, item);
            }
            ExternalNestedImpl(){
                    this.builder = new V2beta2ExternalMetricStatusBuilder(this);
            }
    
    public N and(){
            return (N) V2beta2MetricStatusFluentImpl.this.withExternal(builder.build());
    }
    public N endExternal(){
            return and();
    }

}
    public class ObjectNestedImpl<N> extends V2beta2ObjectMetricStatusFluentImpl<V2beta2MetricStatusFluent.ObjectNested<N>> implements V2beta2MetricStatusFluent.ObjectNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V2beta2ObjectMetricStatusBuilder builder;
    
            ObjectNestedImpl(V2beta2ObjectMetricStatus item){
                    this.builder = new V2beta2ObjectMetricStatusBuilder(this, item);
            }
            ObjectNestedImpl(){
                    this.builder = new V2beta2ObjectMetricStatusBuilder(this);
            }
    
    public N and(){
            return (N) V2beta2MetricStatusFluentImpl.this.withObject(builder.build());
    }
    public N endObject(){
            return and();
    }

}
    public class PodsNestedImpl<N> extends V2beta2PodsMetricStatusFluentImpl<V2beta2MetricStatusFluent.PodsNested<N>> implements V2beta2MetricStatusFluent.PodsNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V2beta2PodsMetricStatusBuilder builder;
    
            PodsNestedImpl(V2beta2PodsMetricStatus item){
                    this.builder = new V2beta2PodsMetricStatusBuilder(this, item);
            }
            PodsNestedImpl(){
                    this.builder = new V2beta2PodsMetricStatusBuilder(this);
            }
    
    public N and(){
            return (N) V2beta2MetricStatusFluentImpl.this.withPods(builder.build());
    }
    public N endPods(){
            return and();
    }

}
    public class ResourceNestedImpl<N> extends V2beta2ResourceMetricStatusFluentImpl<V2beta2MetricStatusFluent.ResourceNested<N>> implements V2beta2MetricStatusFluent.ResourceNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V2beta2ResourceMetricStatusBuilder builder;
    
            ResourceNestedImpl(V2beta2ResourceMetricStatus item){
                    this.builder = new V2beta2ResourceMetricStatusBuilder(this, item);
            }
            ResourceNestedImpl(){
                    this.builder = new V2beta2ResourceMetricStatusBuilder(this);
            }
    
    public N and(){
            return (N) V2beta2MetricStatusFluentImpl.this.withResource(builder.build());
    }
    public N endResource(){
            return and();
    }

}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V2beta2MetricStatusFluentImpl.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Boolean;
import java.lang.StringBuffer;
import java.lang.Object;

public class V2beta2MetricStatusFluentImpl<A extends V2beta2MetricStatusFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V2beta2MetricStatusFluent<A>{

    private V2beta2ExternalMetricStatusBuilder external;
    private V2beta2ObjectMetricStatusBuilder object;
    private V2beta2PodsMetricStatusBuilder pods;
    private V2beta2ResourceMetricStatusBuilder resource;
    private String type;

    public V2beta2MetricStatusFluentImpl(){
    }
    public V2beta2MetricStatusFluentImpl(V2beta2MetricStatus instance){
            this.withExternal(instance.getExternal());

            this.withObject(instance.getObject());

            this.withPods(instance.getPods());

            this.withResource(instance.getResource());

            this.withType(instance.getType());

    }

    
/**
 * This method has been deprecated, please use method buildExternal instead.
 * @return The buildable object.
 */
@Deprecated public V2beta2ExternalMetricStatus getExternal(){
            return this.external!=null?this.external.build():null;
    }

    public V2beta2ExternalMetricStatus buildExternal(){
            return this.external!=null?this.external.build():null;
    }

    public A withExternal(V2beta2ExternalMetricStatus external){
            _visitables.get("external").remove(this.external);
            if (external!=null){ this.external= new V2beta2ExternalMetricStatusBuilder(external); _visitables.get("external").add(this.external);} return (A) this;
    }

    public Boolean hasExternal(){
            return this.external != null;
    }

    public V2beta2MetricStatusFluent.ExternalNested<A> withNewExternal(){
            return new ExternalNestedImpl();
    }

    public V2beta2MetricStatusFluent.ExternalNested<A> withNewExternalLike(V2beta2ExternalMetricStatus item){
            return new ExternalNestedImpl(item);
    }

    public V2beta2MetricStatusFluent.ExternalNested<A> editExternal(){
            return withNewExternalLike(getExternal());
    }

    public V2beta2MetricStatusFluent.ExternalNested<A> editOrNewExternal(){
            return withNewExternalLike(getExternal() != null ? getExternal(): new V2beta2ExternalMetricStatusBuilder().build());
    }

    public V2beta2MetricStatusFluent.ExternalNested<A> editOrNewExternalLike(V2beta2ExternalMetricStatus item){
            return withNewExternalLike(getExternal() != null ? getExternal(): item);
    }

    
/**
 * This method has been deprecated, please use method buildObject instead.
 * @return The buildable object.
 */
@Deprecated public V2beta2ObjectMetricStatus getObject(){
            return this.object!=null?this.object.build():null;
    }

    public V2beta2ObjectMetricStatus buildObject(){
            return this.object!=null?this.object.build():null;
    }

    public A withObject(V2beta2ObjectMetricStatus object){
            _visitables.get("object").remove(this.object);
            if (object!=null){ this.object= new V2beta2ObjectMetricStatusBuilder(object); _visitables.get("object").add(this.object);} return (A) this;
    }

    public Boolean hasObject(){
            return this.object != null;
    }

    public V2beta2MetricStatusFluent.ObjectNested<A> withNewObject(){
            return new ObjectNestedImpl();
    }

    public V2beta2MetricStatusFluent.ObjectNested<A> withNewObjectLike(V2beta2ObjectMetricStatus item){
            return new ObjectNestedImpl(item);
    }

    public V2beta2MetricStatusFluent.ObjectNested<A> editObject(){
            return withNewObjectLike(getObject());
    }

    public V2beta2MetricStatusFluent.ObjectNested<A> editOrNewObject(){
            return withNewObjectLike(getObject() != null ? getObject(): new V2beta2ObjectMetricStatusBuilder().build());
    }

    public V2beta2MetricStatusFluent.ObjectNested<A> editOrNewObjectLike(V2beta2ObjectMetricStatus item){
            return withNewObjectLike(getObject() != null ? getObject(): item);
    }

    
/**
 * This method has been deprecated, please use method buildPods instead.
 * @return The buildable object.
 */
@Deprecated public V2beta2PodsMetricStatus getPods(){
            return this.pods!=null?this.pods.build():null;
    }

    public V2beta2PodsMetricStatus buildPods(){
            return this.pods!=null?this.pods.build():null;
    }

    public A withPods(V2beta2PodsMetricStatus pods){
            _visitables.get("pods").remove(this.pods);
            if (pods!=null){ this.pods= new V2beta2PodsMetricStatusBuilder(pods); _visitables.get("pods").add(this.pods);} return (A) this;
    }

    public Boolean hasPods(){
            return this.pods != null;
    }

    public V2beta2MetricStatusFluent.PodsNested<A> withNewPods(){
            return new PodsNestedImpl();
    }

    public V2beta2MetricStatusFluent.PodsNested<A> withNewPodsLike(V2beta2PodsMetricStatus item){
            return new PodsNestedImpl(item);
    }

    public V2beta2MetricStatusFluent.PodsNested<A> editPods(){
            return withNewPodsLike(getPods());
    }

    public V2beta2MetricStatusFluent.PodsNested<A> editOrNewPods(){
            return withNewPodsLike(getPods() != null ? getPods(): new V2beta2PodsMetricStatusBuilder().build());
    }

    public V2beta2MetricStatusFluent.PodsNested<A> editOrNewPodsLike(V2beta2PodsMetricStatus item){
            return withNewPodsLike(getPods() != null ? getPods(): item);
    }

    
/**
 * This method has been deprecated, please use method buildResource instead.
 * @return The buildable object.
 */
@Deprecated public V2beta2ResourceMetricStatus getResource(){
            return this.resource!=null?this.resource.build():null;
    }

    public V2beta2ResourceMetricStatus buildResource(){
            return this.resource!=null?this.resource.build():null;
    }

    public A withResource(V2beta2ResourceMetricStatus resource){
            _visitables.get("resource").remove(this.resource);
            if (resource!=null){ this.resource= new V2beta2ResourceMetricStatusBuilder(resource); _visitables.get("resource").add(this.resource);} return (A) this;
    }

    public Boolean hasResource(){
            return this.resource != null;
    }

    public V2beta2MetricStatusFluent.ResourceNested<A> withNewResource(){
            return new ResourceNestedImpl();
    }

    public V2beta2MetricStatusFluent.ResourceNested<A> withNewResourceLike(V2beta2ResourceMetricStatus item){
            return new ResourceNestedImpl(item);
    }

    public V2beta2MetricStatusFluent.ResourceNested<A> editResource(){
            return withNewResourceLike(getResource());
    }

    public V2beta2MetricStatusFluent.ResourceNested<A> editOrNewResource(){
            return withNewResourceLike(getResource() != null ? getResource(): new V2beta2ResourceMetricStatusBuilder().build());
    }

    public V2beta2MetricStatusFluent.ResourceNested<A> editOrNewResourceLike(V2beta2ResourceMetricStatus item){
            return withNewResourceLike(getResource() != null ? getResource(): item);
    }

    public String getType(){
            return this.type;
    }

    public A withType(String type){
            this.type=type; return (A) this;
    }

    public Boolean hasType(){
            return this.type != null;
    }

    public A withNewType(String arg1){
            return (A)withType(new String(arg1));
    }

    public A withNewType(StringBuilder arg1){
            return (A)withType(new String(arg1));
    }

    public A withNewType(StringBuffer arg1){
            return (A)withType(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V2beta2MetricStatusFluentImpl that = (V2beta2MetricStatusFluentImpl) o;
            if (external != null ? !external.equals(that.external) :that.external != null) return false;
            if (object != null ? !object.equals(that.object) :that.object != null) return false;
            if (pods != null ? !pods.equals(that.pods) :that.pods != null) return false;
            if (resource != null ? !resource.equals(that.resource) :that.resource != null) return false;
            if (type != null ? !type.equals(that.type) :that.type != null) return false;
            return true;
    }


    public class ExternalNestedImpl<N> extends V2beta2ExternalMetricStatusFluentImpl<V2beta2MetricStatusFluent.ExternalNested<N>> implements V2beta2MetricStatusFluent.ExternalNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V2beta2ExternalMetricStatusBuilder builder;
    
            ExternalNestedImpl(V2beta2ExternalMetricStatus item){
                    this.builder = new V2beta2ExternalMetricStatusBuilder(this, item);
            }
            ExternalNestedImpl(){
                    this.builder = new V2beta2ExternalMetricStatusBuilder(this);
            }
    
    public N and(){
            return (N) V2beta2MetricStatusFluentImpl.this.withExternal(builder.build());
    }
    public N endExternal(){
            return and();
    }

}
    public class ObjectNestedImpl<N> extends V2beta2ObjectMetricStatusFluentImpl<V2beta2MetricStatusFluent.ObjectNested<N>> implements V2beta2MetricStatusFluent.ObjectNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V2beta2ObjectMetricStatusBuilder builder;
    
            ObjectNestedImpl(V2beta2ObjectMetricStatus item){
                    this.builder = new V2beta2ObjectMetricStatusBuilder(this, item);
            }
            ObjectNestedImpl(){
                    this.builder = new V2beta2ObjectMetricStatusBuilder(this);
            }
    
    public N and(){
            return (N) V2beta2MetricStatusFluentImpl.this.withObject(builder.build());
    }
    public N endObject(){
            return and();
    }

}
    public class PodsNestedImpl<N> extends V2beta2PodsMetricStatusFluentImpl<V2beta2MetricStatusFluent.PodsNested<N>> implements V2beta2MetricStatusFluent.PodsNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V2beta2PodsMetricStatusBuilder builder;
    
            PodsNestedImpl(V2beta2PodsMetricStatus item){
                    this.builder = new V2beta2PodsMetricStatusBuilder(this, item);
            }
            PodsNestedImpl(){
                    this.builder = new V2beta2PodsMetricStatusBuilder(this);
            }
    
    public N and(){
            return (N) V2beta2MetricStatusFluentImpl.this.withPods(builder.build());
    }
    public N endPods(){
            return and();
    }

}
    public class ResourceNestedImpl<N> extends V2beta2ResourceMetricStatusFluentImpl<V2beta2MetricStatusFluent.ResourceNested<N>> implements V2beta2MetricStatusFluent.ResourceNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V2beta2ResourceMetricStatusBuilder builder;
    
            ResourceNestedImpl(V2beta2ResourceMetricStatus item){
                    this.builder = new V2beta2ResourceMetricStatusBuilder(this, item);
            }
            ResourceNestedImpl(){
                    this.builder = new V2beta2ResourceMetricStatusBuilder(this);
            }
    
    public N and(){
            return (N) V2beta2MetricStatusFluentImpl.this.withResource(builder.build());
    }
    public N endResource(){
            return and();
    }

}


}
